@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2019 Marco d'Itri <md@linux.it>.
+ * Copyright (C) 1999-2021 Marco d'Itri <md@linux.it>.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -693,7 +693,10 @@ char *queryformat(const char *server, const char *flags, const char *query)
 	    strcat(buf, "a ");
 	    strcat(buf, query + 2);
 	} else if (myinet_aton(query) || strchr(query, ':')) {
-	    strcat(buf, "n + ");
+	    if (strchr(query, '/'))
+		strcat(buf, "r + = ");
+	    else
+		strcat(buf, "n + ");
 	    strcat(buf, query);
 	} else
 	    strcat(buf, query);
